main library
The entry point of the disposito analyzer plugin.
The analysis server generates code that imports this library and reads the top-level plugin variable, so neither the path of this file nor the name of that variable may change.
Properties
- plugin → DispositoPlugin
-
The plugin instance loaded by the analysis server.
final